@@ -89,7 +89,7 @@ sub _generic {
 sub _youtube_video_id {
     my ( $opt, $webpage_url ) = @_;
     my $invalid_char = $opt->{invalid_char};
-    return     if ! $opt->{fast_list_youtube}; #
+    return     if ! $opt->{fast_list_youtube};
     return     if ! $webpage_url;
     return $1  if   $webpage_url =~ m{^([\p{PerlWord}-]{11})\z};
     return     if   $webpage_url !~ $opt->{yt_regexp};
@@ -104,7 +104,7 @@ sub _youtube_video_id {
 #sub _youtube_playlist_id {
 #    my ( $opt, $webpage_url ) = @_;
 #    my $invalid_char = $opt->{invalid_char};
-#    return    if ! $opt->{fast_list_youtube}; # && ! $opt->{fast_list_youtube};
+#    return    if ! $opt->{fast_list_youtube};
 #    return    if ! $webpage_url;
 #    return    if   $webpage_url !~ $opt->{yt_regexp};
 #    return $1 if   $webpage_url =~ m{/.*?[?&;!]list=([^$invalid_char]+)};
@@ -115,7 +115,7 @@ sub _youtube_video_id {
 sub _youtube_user_id {
     my ( $opt, $webpage_url ) = @_;
     my $invalid_char = $opt->{invalid_char};
-    return    if ! $opt->{small_list_size}; # && ! $opt->{fast_list_youtube};
+    return    if ! $opt->{fast_list_youtube};
     return    if ! $webpage_url;
     return    if   $webpage_url !~ $opt->{yt_regexp};
     return $1 if   $webpage_url =~ m{/user/([^$invalid_char]+)};
