@@ -8,26 +8,27 @@ use 5.010000;
 use Exporter qw( import );
 our @EXPORT_OK = qw( get_vimeo_list_info get_youtube_list_info get_new_video_url get_download_info );
 
-use JSON                qw( decode_json );
-use LWP::UserAgent      qw();
-#use Mojo::DOM          qw(); # required
-use Term::ANSIScreen    qw( :screen );
+use JSON             qw( decode_json );
+use LWP::UserAgent   qw();
+#use Mojo::DOM       qw(); # required
+use Term::ANSIScreen qw( :screen );
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
-use App::YTDL::DataExtract qw( json_to_hash );
-use App::YTDL::Helper      qw( uni_capture HIDE_CURSOR SHOW_CURSOR );
+use App::YTDL::DataExtract  qw( json_to_hash );
+use App::YTDL::Helper       qw( uni_capture HIDE_CURSOR SHOW_CURSOR );
+use App::YTDL::LWPUserAgent qw();
 
 
 
 sub get_youtube_list_info {
     my ( $opt, $url ) = @_;
-    my $ua = LWP::UserAgent->new(
+    my $ua = App::YTDL::LWPUserAgent->new(
         agent         => $opt->{useragent},
         timeout       => $opt->{timeout},
         show_progress => 1
     );
-    eval { require Mojo::DOM } or die $@;
+    require Mojo::DOM;
     my $tmp = [];
     my $next;
     my $count = 0;
@@ -35,43 +36,37 @@ sub get_youtube_list_info {
     RETRY: while ( 1 ) {
         $count++;
         if ( eval {
+            $ua->{page} = 1;
             my $res = $ua->get( $url );
             die $res->status_line, ': ', $url if ! $res->is_success;
-            my $date_sort = 0;
-            my $dom = Mojo::DOM->new( $res->decoded_content );
+            my $content = $res->decoded_content;
+            my $dom = Mojo::DOM->new( $content );
             my $uploader = $dom->at( 'meta[itemprop="name"][content]' )->attr( 'content' );
-            $dom->find( 'li[class="channels-content-item yt-shelf-grid-item"]' )
-                ->each(
-                    sub {
-                        my $duration        = $_->at(  'span[class="video-time"] > span[title]' )->text;
-                        my $title           = $_->at(  'h3[class="yt-lockup-title"] > a[class]' )->attr( 'title' );
-                        my $video_id        = $_->at(  'h3[class="yt-lockup-title"] > a[class]' )->attr( 'href' );
-                        my $view_count      = $_->find( 'ul[class="yt-lockup-meta-info"] > li' )->[0]->text;
-                        my $upload_date_rel = $_->find( 'ul[class="yt-lockup-meta-info"] > li' )->[1]->text;
-                        $video_id =~ s/^.+=(?=[^=]{11}\z)//;
-                        $view_count =~ s/^([0-9.,]+).+\z/$1/;
-                        $view_count =~ s/[,.]//g;
-                        if ( $duration =~ /^(?:\d\d?:){0,2}\d\d?\z/ ) {
-                            my $seconds = 0;
-                            my @u = ( 1, 60, 3600 );
-                            my @parts = reverse split ':', $duration;
-                            for my $i ( 0 .. $#parts ) {
-                                $seconds += $parts[$i] * $u[$i];
-                            }
-                            $duration = $seconds if $seconds;
-                        }
-                        push @$tmp, {
-                            date_sort       => ++$date_sort,
-                            duration        => $duration,
-                            video_id        => $video_id,
-                            title           => $title,
-                            uploader        => $uploader,
-                            view_count      => $view_count,
-                            upload_date_rel => $upload_date_rel,
-                            webpage_url     => sprintf( 'https://www.youtube.com/watch?v=%s', $video_id ),
-                        };
-                    }
-                );
+            my $load_more_widget_html;
+            my $more_button = $dom->at( 'button[class*="browse-items-load-more-button"][data-uix-load-more-href]' );
+            _parse_yt_list_html( $content, $uploader, $tmp );
+            if ( $more_button ) {
+                $load_more_widget_html = $more_button->to_string;
+            }
+
+            PAGE: while ( $load_more_widget_html ) {
+                my $url;
+                if ( $load_more_widget_html =~ /data-uix-load-more-href="([^"]+)"/ ) {
+                    $url = sprintf 'https://www.youtube.com%s', $1;
+                }
+                last PAGE if ! $url; # die "more_button: could not extract url!";
+                $ua->{page}++;
+                my $next_res = $ua->get( $url );
+                my $h_ref = decode_json( $next_res->decoded_content );
+                last PAGE if $h_ref->{content_html} !~ /\S/;
+                $content = '<!DOCTYPE html><html>' . $h_ref->{content_html} . '</html>';
+                _parse_yt_list_html( $content, $uploader, $tmp );
+                if ( $opt->{small_list_size} ) {
+                   $#$tmp = 49 if @$tmp > 50;
+                   last PAGE;
+                }
+                $load_more_widget_html = $h_ref->{load_more_widget_html};
+            }
             1 }
         ) {
             return $tmp;
@@ -85,6 +80,45 @@ sub get_youtube_list_info {
 }
 
 
+sub _parse_yt_list_html {
+    my ( $content, $uploader, $tmp ) = @_;
+    my $date_sort = @$tmp;
+    my $dom = Mojo::DOM->new( $content );
+    $dom->find( 'li[class="channels-content-item yt-shelf-grid-item"]' )
+        ->each(
+            sub {
+                my $duration        = $_->at(  'span[class="video-time"] > span[title]' )->text;
+                my $title           = $_->at(  'h3[class="yt-lockup-title"] > a[class]' )->attr( 'title' );
+                my $video_id        = $_->at(  'h3[class="yt-lockup-title"] > a[class]' )->attr( 'href' );
+                my $view_count      = $_->find( 'ul[class="yt-lockup-meta-info"] > li' )->[0]->text;
+                my $upload_date_rel = $_->find( 'ul[class="yt-lockup-meta-info"] > li' )->[1]->text;
+                $video_id =~ s/^.+=(?=[^=]{11}\z)//;
+                $view_count =~ s/^([0-9.,]+).+\z/$1/;
+                $view_count =~ s/[,.]//g;
+                if ( $duration =~ /^(?:\d\d?:){0,2}\d\d?\z/ ) {
+                    my $seconds = 0;
+                    my @u = ( 1, 60, 3600 );
+                    my @parts = reverse split ':', $duration;
+                    for my $i ( 0 .. $#parts ) {
+                        $seconds += $parts[$i] * $u[$i];
+                    }
+                    $duration = $seconds if $seconds;
+                }
+                push @$tmp, {
+                    date_sort       => ++$date_sort,
+                    duration        => $duration,
+                    video_id        => $video_id,
+                    title           => $title,
+                    uploader        => $uploader,
+                    view_count      => $view_count,
+                    upload_date_rel => $upload_date_rel,
+                    webpage_url     => sprintf( 'https://www.youtube.com/watch?v=%s', $video_id ),
+                };
+            }
+        );
+}
+
+
 sub get_vimeo_list_info {
     my ( $opt, $url ) = @_;
     my $ua = LWP::UserAgent->new(
@@ -92,7 +126,7 @@ sub get_vimeo_list_info {
         timeout       => $opt->{timeout},
         show_progress => 1
     );
-    eval { require Mojo::DOM } or die $@;
+    require Mojo::DOM;
     my $tmp = [];
     my $next;
     my $count = 0;
