@@ -146,8 +146,10 @@ sub _menus {
 sub _sub_menus {
     my ( $key ) = @_;
     my $sub_menus = {
-        _fast_listmenu => [ [ 'fast_list_vimeo',   "- vimeo",   [ 'NO', 'YES' ] ],
-                          ],
+        _fast_listmenu => [
+            [ 'fast_list_vimeo',   "- vimeo",   [ 'NO', 'YES' ] ],
+            [ 'fast_list_youtube', "- youtube", [ 'NO', 'YES' ] ],
+        ],
     };
     return $sub_menus->{$key} if $key;
     return $sub_menus;
