@@ -36,7 +36,7 @@ sub set_preferred_qualities {
             push @format_ids, $fmt;
         }
     }
-    my $pref_qual = read_json( $opt->{preferred_file} );
+    my $pref_qual = read_json( $opt, $opt->{preferred_file} );
 
     CHOICE: while ( 1 ) {
         my @pre = ( undef );
@@ -48,7 +48,7 @@ sub set_preferred_qualities {
             { prompt => "Set preferred qualities ($ex):", layout => 3, index => 1, undef => '<<' }
         );
         if ( ! $idx_choice ) {
-            write_json( $opt->{preferred_file}, $pref_qual );
+            write_json( $opt, $opt->{preferred_file}, $pref_qual );
             return;
         }
         $idx_choice -= @pre;
@@ -76,7 +76,7 @@ sub fmt_quality {
     my ( $opt, $info, $fmt_list, $ex, $video_id ) = @_;
     my $auto_quality = $opt->{auto_quality};
     my $fmt_ok = 0;
-    if ( $auto_quality eq 'keep_channel_playlist' && $info->{$ex}{$video_id}{from_list} ) {
+    if ( $auto_quality eq 'keep_uploader_playlist' && $info->{$ex}{$video_id}{from_list} ) {
         my $list_id = $info->{$ex}{$video_id}{playlist_id};
         if ( ! length $list_id ) {
             $list_id = $info->{$ex}{$video_id}{uploader_id};
@@ -106,7 +106,7 @@ sub fmt_quality {
 
     }
     elsif ( $auto_quality eq 'preferred' ) {
-        my $pref_qual = read_json( $opt->{preferred_file} );
+        my $pref_qual = read_json( $opt, $opt->{preferred_file} );
         my @pref_qualities = @{$pref_qual->{$ex}};
         PQ: for my $slot ( @pref_qualities ) {
             for my $fmt ( @$slot ) {
